.. currentmodule:: sardana.tango.pool.Controller

:mod:`~sardana.tango.pool.Controller`
=====================================

.. automodule:: sardana.tango.pool.Controller

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`Controller`
    * :class:`ControllerClass`

Controller
----------

.. inheritance-diagram:: Controller
    :parts: 1
    
.. autoclass:: Controller
    :show-inheritance:
    :members:
    :undoc-members:

ControllerClass
---------------

.. inheritance-diagram:: ControllerClass
    :parts: 1
    
.. autoclass:: ControllerClass
    :show-inheritance:
    :members:
    :undoc-members:

